@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2020 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 var quill = undefined;
 var Delta = Quill.import ("delta");
+var chapterEditorUniqueID = Math.floor (Math.random() * 100000000);
 
 
 $ (document).ready (function ()
@@ -90,7 +91,7 @@ function editorInitialize ()
     return new Delta().insert (plaintext);
   });
 
-  if (editorWriteAccess) if (!quill.hasFocus ()) quill.focus (); // Todo
+  if (editorWriteAccess) if (!quill.hasFocus ()) quill.focus ();
   
   // Event handlers.
   quill.on ("text-change", editorTextChangeHandler);
@@ -174,11 +175,19 @@ function editorLoadChapter (reload)
   $.ajax ({
     url: "load",
     type: "GET",
-    data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter },
+    data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, id: chapterEditorUniqueID },
     success: function (response) {
       // Set the editor read-write or read-only.
       editorWriteAccess = checksum_readwrite (response);
-      if (editorForceReadOnly) editorWriteAccess = false;
+      // If this is the second or third or higher editor in the workspace,
+      // make the editor read-only.
+      if (window.frameElement) {
+        iframe = $(window.frameElement);
+        var data_editor_number = iframe.attr("data-editor-no");
+        if (data_editor_number > 1) {
+          editorWriteAccess = false;
+        }
+      }
       // Checksumming.
       response = checksum_receive (response);
       if (response !== false) {
@@ -209,7 +218,7 @@ function editorLoadChapter (reload)
         editorLoadDate = new Date();
         var seconds = (editorLoadDate.getTime() - editorSaveDate.getTime()) / 1000;
         if ((seconds < 2) || reload) {
-          if (editorWriteAccess) alert (editorChapterVerseUpdatedLoaded);
+          if (editorWriteAccess) editorReloadAlert (editorChapterVerseUpdatedLoaded); // Todo
         }
       } else {
         // Checksum error: Reload.
@@ -246,7 +255,7 @@ function editorSaveChapter (sync)
     url: "save",
     type: "POST",
     async: editorSaveAsync,
-    data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, html: encodedHtml, checksum: checksum },
+    data: { bible: editorLoadedBible, book: editorLoadedBook, chapter: editorLoadedChapter, html: encodedHtml, checksum: checksum, id: chapterEditorUniqueID },
     success: function (response) {
       editorStatus (response);
       if (response == editorChapterReformat) {
@@ -266,7 +275,7 @@ function editorSaveChapter (sync)
       editorSaveDate = new Date();
       var seconds = (editorSaveDate.getTime() - editorLoadDate.getTime()) / 1000;
       if (seconds < 2) {
-        if (editorWriteAccess) alert (editorChapterVerseUpdatedLoaded);
+        if (editorWriteAccess) editorReloadAlert (editorChapterVerseUpdatedLoaded); // Todo
       }
     },
   });
@@ -294,7 +303,7 @@ function editorGetHtml ()
 
 /*
 
-Portion dealing with triggers for editor's content change.
+Portion dealing with triggers for when the editor's content changes.
 
 */
 
@@ -660,7 +669,7 @@ function editorScrollVerseIntoView ()
   var bounds = quill.getBounds (position);
   var workspaceHeight = $("#workspacewrapper").height();
   var currentScrollTop = $("#workspacewrapper").scrollTop();
-  var scrollTo = bounds.top - (workspaceHeight /  2);
+  var scrollTo = bounds.top - (workspaceHeight * verticalCaretPosition / 100);
   scrollTo = parseInt (scrollTo);
   var lowerBoundary = currentScrollTop - (workspaceHeight / 10);
   var upperBoundary = currentScrollTop + (workspaceHeight / 10);
@@ -879,7 +888,7 @@ Section for the notes.
 var editorInsertedNotesCount = 0;
 
 
-function applyNotesStyle (style)
+function applyNotesStyle (style) // Todo
 {
   if (!editorWriteAccess) return;
 
@@ -903,14 +912,9 @@ function applyNotesStyle (style)
   quill.setSelection (caret, 0);
   quill.insertText (caret, caller, "character", "notecall" + noteId, "user");
 
-  // Append note text to notes section:
-  // <p class="b-f"><span class="i-notebody1">1</span> + .</p>
-  var length = quill.getLength ();
-  quill.insertText (length, "\n", "paragraph", style, "user");
-  quill.insertText (length, caller, "character", "notebody" + noteId, "user");
-  length++;
-  quill.insertText (length, " + .", "character", "", "user");
-  
+  // Append note text to notes section. Todo
+  assetsEditorAddNote (quill, style, caller, noteId, editorNavigationChapter, editorNavigationVerse);
+
   editorInsertedNotesCount++;
   
   editorActiveStylesFeedback ();
@@ -1046,3 +1050,27 @@ function editorSwipeRight (event)
 }
 
 
+/*
+
+Section for reload notifications.
+
+*/
+
+
+function editorReloadAlert (message) // Todo
+{
+  // Take action only if the editor has focus and the user can type in it.
+  if (quill.hasFocus ()) {
+    notifyItSuccess (message)
+    quill.enable (false);
+    setTimeout (editorReloadAlertTimeout, 3000);
+  }
+}
+
+
+function editorReloadAlertTimeout ()
+{
+  quill.enable (editorWriteAccess);
+  quill.focus ();
+}
+
