@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2020 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -46,6 +46,26 @@ vector <string> filter_string_explode (string value, char delimiter)
 }
 
 
+// Explodes an input string on multiple delimiters.
+vector <string> filter_string_explode (string value, string delimiters)
+{
+  vector <string> result;
+  while (!value.empty ()) {
+    size_t pos = value.find_first_of (delimiters);
+    if (pos == string::npos) {
+      result.push_back (value);
+      value.clear ();
+    } else {
+      string s = value.substr (0, pos);
+      if (!s.empty()) result.push_back (s);
+      pos++;
+      value.erase (0, pos);
+    }
+  }
+  return result;
+}
+
+
 // A C++ equivalent for PHP's implode function.
 // Join a vector of string, with delimiters, into a string.
 // Return this string.
@@ -1408,6 +1428,7 @@ string emoji_heavy_plus_sign ()
 // Move the $item $up (towards the beginning), or else down (towards the end).
 void array_move_up_down (vector <string> & container, size_t item, bool up)
 {
+  if (container.empty ()) return;
   if (up) {
     if (item > 0) {
       if (item < container.size ()) {
