@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2020 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <edit/index.h>
 #include <editone/index.h>
 #include <editusfm/index.h>
-#include <editverse/index.h>
 #include <email/index.h>
 #include <filter/string.h>
 #include <filter/roles.h>
@@ -405,6 +404,7 @@ string menu_logic_translate_category (void * webserver_request, string * tooltip
     }
   }
 #endif
+  (void) request;
   
   if (!html.empty ()) {
     html.insert (html.begin (), menu_logic_translate_text () + ": ");
@@ -842,6 +842,8 @@ string menu_logic_settings_category (void * webserver_request, string * tooltip)
     }
 
   }
+
+  (void) request;
   
   if (!html.empty ()) {
     string user = request->session_logic ()->currentUser ();
